==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fRet.h <==
// class soot.coffi.Instruction_Ret

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class c9beb81b8043e345 soot_coffi_Instruction__5fRet
// @dep_class 73e8eecee99f809f soot_coffi_Instruction__5fbytevar

// header file dependencies
// @dep_header soot_coffi_Instruction__5fbytevar

#include "soot/coffi/Instruction__5fbytevar.h"

#ifndef _JC_soot_coffi_Instruction__5fRet_H_
#define _JC_soot_coffi_Instruction__5fRet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fRet$sub_refs	_jc_soot_coffi_Instruction__5fRet$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fRet$sub_nonrefs	_jc_soot_coffi_Instruction__5fRet$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fRet$refs	_jc_soot_coffi_Instruction__5fRet$refs;
typedef struct _jc_soot_coffi_Instruction__5fRet$nonrefs	_jc_soot_coffi_Instruction__5fRet$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fRet$object	_jc_soot_coffi_Instruction__5fRet$object;

typedef const struct _jc_soot_coffi_Instruction__5fRet$vmethods	_jc_soot_coffi_Instruction__5fRet$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fRet$vtable	_jc_soot_coffi_Instruction__5fRet$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fRet$vtype	_jc_soot_coffi_Instruction__5fRet$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fRet$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fRet$object *);

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fRet$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fRet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbytevar$vmethods	soot_coffi_Instruction__5fbytevar;
	_jc_soot_coffi_Instruction__5fRet$vmethods	soot_coffi_Instruction__5fRet;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fRet$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fRet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fRet$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fRet$refs {
    _jc_soot_coffi_Instruction__5fRet$sub_refs	soot_coffi_Instruction__5fRet;
    _jc_soot_coffi_Instruction__5fbytevar$sub_refs	soot_coffi_Instruction__5fbytevar;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fRet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fRet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbytevar$sub_nonrefs	soot_coffi_Instruction__5fbytevar;
    _jc_soot_coffi_Instruction__5fRet$sub_nonrefs	soot_coffi_Instruction__5fRet;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fRet$object {
	_jc_soot_coffi_Instruction__5fRet$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fRet$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fRet$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fRet$vtype _jc_soot_coffi_Instruction__5fRet$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fRet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fRet$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fRet_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fRet.h <==
// class soot.coffi.Instruction_Ret

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class c9beb81b8043e345 soot_coffi_Instruction__5fRet
// @dep_class 73e8eecee99f809f soot_coffi_Instruction__5fbytevar

// header file dependencies
// @dep_header soot_coffi_Instruction__5fbytevar

#include "soot/coffi/Instruction__5fbytevar.h"

#ifndef _JC_soot_coffi_Instruction__5fRet_H_
#define _JC_soot_coffi_Instruction__5fRet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fRet$sub_refs	_jc_soot_coffi_Instruction__5fRet$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fRet$sub_nonrefs	_jc_soot_coffi_Instruction__5fRet$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fRet$refs	_jc_soot_coffi_Instruction__5fRet$refs;
typedef struct _jc_soot_coffi_Instruction__5fRet$nonrefs	_jc_soot_coffi_Instruction__5fRet$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fRet$object	_jc_soot_coffi_Instruction__5fRet$object;

typedef const struct _jc_soot_coffi_Instruction__5fRet$vmethods	_jc_soot_coffi_Instruction__5fRet$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fRet$vtable	_jc_soot_coffi_Instruction__5fRet$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fRet$vtype	_jc_soot_coffi_Instruction__5fRet$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fRet$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fRet$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fRet$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fRet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbytevar$vmethods	soot_coffi_Instruction__5fbytevar;
	_jc_soot_coffi_Instruction__5fRet$vmethods	soot_coffi_Instruction__5fRet;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fRet$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fRet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fRet$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fRet$refs {
    _jc_soot_coffi_Instruction__5fRet$sub_refs	soot_coffi_Instruction__5fRet;
    _jc_soot_coffi_Instruction__5fbytevar$sub_refs	soot_coffi_Instruction__5fbytevar;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fRet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fRet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbytevar$sub_nonrefs	soot_coffi_Instruction__5fbytevar;
    _jc_soot_coffi_Instruction__5fRet$sub_nonrefs	soot_coffi_Instruction__5fRet;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fRet$object {
	_jc_soot_coffi_Instruction__5fRet$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fRet$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fRet$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fRet$vtype _jc_soot_coffi_Instruction__5fRet$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fRet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fRet$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fRet_H_ */
